@@ -44,7 +44,7 @@ class LoadSheddingError(Exception):
     pass
 
 
-def get_areas(provider: Provider, search_text: str = None, max_results: int = None) -> List[Any]:
+def get_areas(provider: Provider, search_text: str = None, max_results: int = None) -> List[Area]:
     try:
         areas = provider.get_areas(search_text, max_results)
     except ProviderError as e:
@@ -53,14 +53,22 @@ def get_areas(provider: Provider, search_text: str = None, max_results: int = No
         return areas
 
 
-def get_stage(provider: Provider) -> Stage:
+def get_stage(provider: Provider, coct_stage: bool = False) -> Stage:
     try:
-        stage = provider.get_stage()
+        stage = provider.get_stage(coct_stage=coct_stage)
     except Exception as e:
         raise ProviderError(f"Unable to get stage from {provider.name}.") from e
     return stage
 
 
+def get_stages(provider: Provider) -> List[Stage]:
+    try:
+        stages = provider.get_stages()
+    except Exception as e:
+        raise ProviderError(f"Unable to get stage from {provider.name}.") from e
+    return stages
+
+
 def get_stage_forecast(provider: Provider) -> List[Dict]:
     try:
         if not provider:
@@ -68,7 +76,8 @@ def get_stage_forecast(provider: Provider) -> List[Dict]:
         stage_forecast = provider.get_stage_forecast()
     except Exception as e:
         raise ProviderError(f"Unable to get stage forecast from {provider.name}.") from e
-    return stage_forecast
+    else:
+        return stage_forecast
 
 
 def get_area_forecast(area_schedule: List, planned: dict, now: datetime = datetime.now(timezone.utc)) -> List:
