@@ -13,10 +13,9 @@
 #
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
+from datetime import timezone
 from typing import List, Tuple
 
-from load_shedding.providers.eskom import Eskom
 from load_shedding.libs import coct
 from load_shedding.providers import eskom, ProviderError, to_utc
 from load_shedding.providers import Province, Stage, Area
@@ -58,13 +57,36 @@ class CoCT(eskom.Eskom):
             area_schedule = to_utc(area_schedule)
             return area_schedule
 
-    def get_stage(self) -> Stage:
-        """ Get Stage from Eskom API since we don't have one for CoCT yet."""
+    def get_stage(self, coct_stage: bool = False) -> Stage:
+        """ Get Stage from CoCT API."""
         try:
-            provider = Eskom()
-            stage = provider.get_stage()
+            info = coct.get_info()
+            stage = info[0].get("current_stage")
         except Exception as e:
             raise ProviderError(e)
         else:
-            return stage
+            return Stage(stage)
 
+    def get_stage_forecast(self) -> list:
+        """ Get Stage forecast from CoCT."""
+        try:
+            info = coct.get_info()
+            stage = info[0].get("current_stage")
+            start_time = info[0].get("start_time")
+            end_time = info[0].get("next_stage_start_time")
+
+            next_stage = info[0].get("next_stage")
+            next_start_time = info[0].get("next_stage_start_time")
+            next_end_time = info[0].get("next_stage_start_time")
+        except Exception as e:
+            raise ProviderError(e) from e
+        else:
+            return [{
+                "stage": Stage(stage),
+                "start_time": start_time.astimezone(timezone.utc),
+                "end_time": end_time.astimezone(timezone.utc),
+            }, {
+                "stage": Stage(next_stage),
+                "start_time": next_start_time.astimezone(timezone.utc),
+                "end_time": next_end_time.astimezone(timezone.utc),
+            }]
